@@ -3,35 +3,6 @@ import datetime
 import requests
 
 
-def get_day(days: int = 0):
-    """
-    返回的日期格式 %Y-%m-%d
-    :param days: 距离今天的天数
-    :return: 格式 %Y-%m-%d
-    """
-    return (datetime.datetime.now() + datetime.timedelta(days=days)).strftime("%Y-%m-%d")
-
-
-def get_time(str_time=None, fix=True):
-    """
-    获取分钟时间
-    :param fix: 获取以30分钟为分度的分钟时间
-    :param str_time: 格式 %H:%M 范围: 7:30 - 22:30
-    :return: int: 分钟
-    """
-    if str_time is None:
-        str_time = datetime.datetime.now().strftime("%H:%M")
-        fix = False
-    if len(str(str_time).split(":")) == 1:
-        hour = datetime.datetime.now().hour + int(str_time)
-        minute = datetime.datetime.now().minute
-    else:
-        hour = int(str_time.split(":")[0])
-        minute = int((int(str_time.split(":")[1]) // 30)
-                    * 30) if fix else int(str_time.split(":")[1])
-    return minute + hour * 60
-
-
 class User:
     def __return_and_log(self, json):
         if self.log_status:
